@@ -1,4 +1,7 @@
 from __future__ import unicode_literals
+
+from defusedxml import ElementTree
+
 from .xmlutils import parse_xml
 from .xibutils import get_object_id
 
@@ -7,7 +10,16 @@ class XibContext(object):
     def __init__(self, path):
         self.path = path
         self.success = True
-        self.tree = parse_xml(path)
+        self.errors = []
+        try:
+            self.tree = parse_xml(path)
+        except ElementTree.ParseError as ex:
+            self.tree = None
+            self.errors.append({
+                'file': self.path,
+                'line': ex.position[0],
+                'error': ex.msg,
+            })
         self.rule_name = None
 
     @staticmethod
@@ -25,15 +37,23 @@ class XibContext(object):
             if state_normal is not None:
                 return state_normal.get('title') or state_normal.get('image')
 
+        return None
+
     def error(self, element, message, *args):
         self.success = False
         object_id = get_object_id(element)
         moniker = self._get_moniker(element)
-        print("{}:{}: error: {}{}{} [rule: {}]".format(
-            self.path,
-            element.line,
+
+        new_error = "{}{}{}".format(
             "{}: ".format(object_id) if object_id else '',
             "'{}': ".format(moniker) if moniker else '',
             message.format(*args),
-            self.rule_name,
-        ))
+        )
+        new_error_dict = {
+            "file": self.path,
+            "line": element.line,
+            "error": new_error,
+            "rule": self.rule_name,
+        }
+
+        self.errors.append(new_error_dict)
